@@ -1,12 +1,10 @@
-/******************************************************************************
-** $Id: print.c,v 1.12 2012-01-29 19:28:01 gene Exp $
-**=============================================================================
+/*** print.c ******************************************************************
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-2012 Gerd Neugebauer
+** (c) 1996-2015 Gerd Neugebauer
 ** 
 ** Net: gene@gerd-neugebauer.de
 ** 
@@ -148,9 +146,9 @@ static void puts_in(s,in,fct)			   /*			     */
 	break;					   /*	                     */
       case '\n':				   /*                        */
 	column = 0;			   	   /*                        */
-        if ( in > 0 ) indent(in,fct);		   /*                        */
+        if ( in > 0 ) indent(in, fct);		   /*                        */
         break;  				   /*			     */
-      default:	 ++column;			   /*			     */
+      default: ++column;			   /*			     */
     }						   /*			     */
   }						   /*			     */
 }						   /*------------------------*/
@@ -158,7 +156,7 @@ static void puts_in(s,in,fct)			   /*			     */
 /*-----------------------------------------------------------------------------
 ** Function:	indent()
 ** Purpose:	Add spaces or tabs to indent to the given column.
-**		the current column is beyond col nothing happens.
+**		If the current column is beyond col then nothing happens.
 **		The resource use.tabs can be used to disable the use of TAB.
 ** Arguments:
 **	col	Target column
@@ -177,7 +175,7 @@ static void indent(col,fct)			   /*			     */
       column += TAB_WIDTH - (column%TAB_WIDTH);	   /*	update column.	     */
     }						   /*			     */
     else					   /* otherwise		     */
-    { (void)(*fct)(' ');			   /*  write a singe space   */
+    { (void)(*fct)(' ');			   /*  write a single space  */
       ++column;					   /*  and advance column.   */
     }						   /*			     */
   }						   /*			     */
@@ -196,7 +194,7 @@ static void indent(col,fct)			   /*			     */
 **	fct	function to use for writing a character.
 ** Returns:	nothing
 **___________________________________________________			     */
-static void line_breaking(t,align,fct)		   /*			     */
+static void line_breaking(t, align, fct)	   /*			     */
   register Uchar *t;				   /* string to print.	     */
   int		 align;				   /* alignment column	     */
   int            (*fct)_ARG((int));		   /*                        */
@@ -208,41 +206,41 @@ static void line_breaking(t,align,fct)		   /*			     */
 						   /*			     */
   while ( is_space(*t) ) ++t;			   /* skip leading spaces    */
 						   /*			     */
-  indent(align,fct);				   /* goto alignment column  */
+  indent(align, fct);				   /* goto alignment column  */
 						   /*			     */
   while ( *t )					   /* as long as sth to print*/
   { s = t;					   /*			     */
 						   /*			     */
-    switch( *t )				   /*			     */
+    switch ( *t )				   /*			     */
     { case '"':					   /* QUOTED PART	     */
-	for ( len=2,++t;			   /*			     */
+	for ( len = 2, ++t;			   /*			     */
 	     *t && *t != '\"';			   /* Search terminating "   */
-	     ++t,++len )			   /*			     */
+	     ++t, ++len )			   /*			     */
 	{ if ( *t == '\\' && *(t+1) != '\0' )	   /* skip over quoted and   */
 	  { ++t; ++len; }			   /*  similar constructs.   */
 	}					   /*			     */
 	if ( *t ) ++t;				   /* skip after end, if poss*/
-	if ( *t ) { end_c = *++t; *t = '\0'; }	   /* save char and mark end.*/
+	if ( *t ) { end_c = *t; *t = '\0'; }	   /* save char and mark end.*/
 	else	  { end_c = *t; }		   /*			     */
 	break;					   /*			     */
       case '{':					   /* BRACED PART	     */
 	brace = 1;				   /*			     */
-	for ( len=2,++t;			   /* find matching brace.   */
-	     *t && brace>0;			   /*			     */
-	     ++t,++len )			   /*			     */
+	for ( len = 2, ++t;			   /* find matching brace.   */
+	     *t && brace > 0;			   /*			     */
+	     ++t, ++len )			   /*			     */
 	{ switch ( *t )				   /*			     */
 	  { case '\\': if ( *(t+1) ) ++t; break;   /* ignore \{ \} etc	     */
 	    case '{': ++brace; break;		   /*			     */
 	    case '}': brace--; break;		   /*			     */
 	  }					   /*			     */
 	}					   /*			     */
-	if ( *t ) { end_c = *++t; *t = '\0'; }	   /* save char and mark end.*/
+	if ( *t ) { end_c = *t; *t = '\0'; }	   /* save char and mark end.*/
 	else	  { end_c = *t; }		   /*			     */
 	break;					   /*			     */
       default:					   /* Now we should have a   */
 	while ( is_allowed(*t) ) ++t;		   /*	SYMBOL		     */
 	end_c = *t; *t = '\0';			   /*			     */
-	s = get_item(symbol(s),symbol_type);	   /*			     */
+	s = get_item(symbol(s), symbol_type);	   /*			     */
 	len = strlen((char*)s);			   /*			     */
     }						   /*			     */
 						   /* Now s is a single	     */
@@ -257,7 +255,7 @@ static void line_breaking(t,align,fct)		   /*			     */
 	s = t;					   /* and we are done	     */
       }						   /*			     */
       else if ( !first )			   /* If sth has been before */
-      { puts_in((Uchar*)"\n# ", align-2, fct);	   /*  start a new line	     */
+      { puts_in((Uchar*)"\n# ", align - 2, fct);   /*  start a new line	     */
 	first = TRUE;				   /*			     */
       }						   /* Now we have to break   */
       else					   /*  a single entry	     */
@@ -270,9 +268,9 @@ static void line_breaking(t,align,fct)		   /*			     */
 	else					   /*                        */
 	  save_ptr = s;				   /*                        */
  						   /*                        */
-	for(ptr = s;				   /* Search next newline    */
-	    ptr <= save_ptr && *ptr != '\n';	   /*  or end of region      */
-	    ptr++) {}				   /*                        */
+	for ( ptr = s;				   /* Search next newline    */
+	      ptr < save_ptr && *ptr != '\n';	   /*  or end of region      */
+	      ptr++ ) {}			   /*                        */
  						   /*                        */
 	if ( *ptr == '\n' )			   /*                        */
 	{ save_ptr = ptr;			   /*                        */
@@ -282,7 +280,7 @@ static void line_breaking(t,align,fct)		   /*			     */
 	  indent(align,fct);	   		   /*			     */
 	  *save_ptr = '\n';			   /* Restore end	     */
 	  len += s - save_ptr - 1;		   /* Update the length	     */
-	  s = save_ptr+1;			   /*			     */
+	  s = save_ptr + 1;			   /*			     */
 	}					   /*                        */
 	else					   /*                        */
 	{					   /*                        */
@@ -291,16 +289,18 @@ static void line_breaking(t,align,fct)		   /*			     */
 	  					   /*			     */
 	  if ( save_ptr == s  )			   /* If no SPC found then   */
 	  { while ( *save_ptr && *save_ptr != ' ' )/*  search one forward.   */
-	    { ++save_ptr; }	   		   /*                        */
+	    { save_ptr++; }	   		   /*                        */
 	  }					   /*                        */
 	  len += s - save_ptr;			   /* Update the length	     */
 	  save_c = *save_ptr; *save_ptr = '\0';	   /* Save and mark end.     */
 	  puts_in(s, align, fct);		   /*                        */
-	  NL;					   /*                        */
-	  indent(align,fct);	   		   /*			     */
+	  if (save_c != 0)			   /*                        */
+	  { NL;					   /*                        */
+	    indent(align, fct);	   		   /*			     */
+	  }					   /*                        */
 	  *save_ptr = save_c;			   /* Restore end	     */
 	  s = save_ptr;	   			   /*			     */
-	  while ( is_space(*s) ) { ++s; len--; }   /* Skip spaces	     */
+	  while ( is_space(*s) ) { s++; len--; }   /* Skip spaces	     */
 	}					   /*                        */
       }						   /*			     */
     }						   /*			     */
@@ -326,7 +326,7 @@ static void line_breaking(t,align,fct)		   /*			     */
 **	fct	function to use for writing a character.
 ** Returns:	nothing
 **___________________________________________________'			     */
-static void print_equation(pre,s,t,align,fct)	   /*			     */
+static void print_equation(pre, s, t, align, fct)  /*			     */
   Uchar *pre;					   /*                        */
   Uchar *s;				   	   /*			     */
   Uchar *t;				   	   /*			     */
@@ -346,11 +346,11 @@ static void print_equation(pre,s,t,align,fct)	   /*			     */
   { indent(rsc_indent,fct);			   /*			     */
     PUTS(pre);		   			   /*			     */
     PUTS(get_item(s,symbol_type));		   /*			     */
-    if ( column>=align-2 && rsc_print_we )	   /*                        */
+    if ( column >= align - 2 && rsc_print_we )	   /*                        */
     { PUTC(' '); }				   /*                        */
     else if ( rsc_eq_right )			   /*                        */
     { indent(align-2,fct); }			   /*			     */
-    else if ( column<align || rsc_print_we )	   /*                        */
+    else if ( column < align || rsc_print_we )	   /*                        */
     { PUTC(' '); }	   			   /*                        */
     PUTC('=');					   /*			     */
     if ( rsc_print_we )	{ PUTC(' '); }		   /*                        */
@@ -370,7 +370,7 @@ static void print_equation(pre,s,t,align,fct)	   /*			     */
 **___________________________________________________			     */
 static int fput_char(c)				   /*                        */
   int c;					   /*                        */
-{ return fputc(c,ofile);			   /*                        */
+{ return fputc(c, ofile);			   /*                        */
 }						   /*------------------------*/
 
 /*-----------------------------------------------------------------------------
@@ -384,14 +384,14 @@ static int fput_char(c)				   /*                        */
 **	start	Initial string used before the type. Should be "@" normally.
 ** Returns:	nothing
 **___________________________________________________			     */
-void fput_record(file,rec,db,start)	   	   /*			     */
+void fput_record(file, rec, db, start)	   	   /*			     */
   FILE	 *file;			   		   /*                        */
   DB	 db;			   		   /*                        */
   Record rec;			   		   /* record to print	     */
   Uchar	 *start;		   	   	   /* initial string = "@"   */
 {						   /*                        */
   ofile = file;					   /*                        */
-  put_record(fput_char,rec,db,start);		   /*                        */
+  put_record(fput_char, rec, db, start);	   /*                        */
 }						   /*------------------------*/
 
  static StringBuffer *osb = NULL;
@@ -406,7 +406,7 @@ void fput_record(file,rec,db,start)	   	   /*			     */
 **___________________________________________________			     */
 static int sput_char(c)				   /*                        */
   int c;					   /*                        */
-{ return sbputchar(c,osb);			   /*                        */
+{ return sbputchar(c, osb);			   /*                        */
 }						   /*------------------------*/
 
 /*-----------------------------------------------------------------------------
@@ -421,15 +421,15 @@ static int sput_char(c)				   /*                        */
 **	start	Initial string used before the type. Should be "@" normally.
 ** Returns:	The string containing the printed representation.
 **___________________________________________________			     */
-char * sput_record(rec,db,start)	   	   /*			     */
+char * sput_record(rec, db, start)	   	   /*			     */
   DB	 db;			   		   /*                        */
   Record rec;			   		   /* record to print	     */
   Uchar	 *start;		   	   	   /* initial string = "@"   */
 {						   /*                        */
   if ( osb == NULL ) osb = sbopen();		   /*                        */
   sbrewind(osb);				   /*                        */
-  put_record(sput_char,rec,db,start);		   /*                        */
-  return sbflush(osb);
+  put_record(sput_char, rec, db, start);	   /*                        */
+  return sbflush(osb);				   /*                        */
 }						   /*------------------------*/
 
 /*-----------------------------------------------------------------------------
@@ -442,30 +442,30 @@ char * sput_record(rec,db,start)	   	   /*			     */
 **		\item[rsc\_parentheses] If this boolean variable is
 **		  |TRUE| then |(| and |)| are used to delimit the
 **		  record. Otherwise |{| and |}| are used.
-**		\item[rsc\_col\_p] This integer variable controlls the
+**		\item[rsc\_col\_p] This integer variable controls the
 **		  indentation of preamble records.
-**		\item[rsc\_col\_s] This integer variable controlls the
+**		\item[rsc\_col\_s] This integer variable controls the
 **		  indentation of string records.
 **
 **		\item[rsc\_expand\_macros] If this boolean variable is
 **		  set then macros are expanded before the record is
 **		  printed. This does not effect the internal
 **		  representation. 
-**		\item[rsc\_col] This integer variable controlls the
+**		\item[rsc\_col] This integer variable controls the
 **		  indentation of normal records.
-**		\item[rsc\_col\_key] This integer variable controlls the
+**		\item[rsc\_col\_key] This integer variable controls the
 **		  indentation of the key in a normal record.
-**		\item[rsc\_newlines] This integer variable controlls
+**		\item[rsc\_newlines] This integer variable controls
 **		  the number of newlines printed after a normal record.
 **
-**		\item[rsc\_linelen] This integer variable controlls
+**		\item[rsc\_linelen] This integer variable controls
 **		  the length of the line. The line breaking algorithm
 **		  is applied if this column is about to be violated.
-**		\item[rsc\_indent] This integer variable controlls the
+**		\item[rsc\_indent] This integer variable controls the
 **		  indentation of equations.
-**		\item[rsc\_eq\_right] This boolean variable controlls
+**		\item[rsc\_eq\_right] This boolean variable controls
 **		  the alignment of the |=| in equations. It it is set
-**		  then the equality sign is flused right. Otherwise it
+**		  then the equality sign is flushed right. Otherwise it
 **		  is flushed left.
 **		\end{description}
 **
@@ -484,7 +484,7 @@ char * sput_record(rec,db,start)	   	   /*			     */
 **	start	Initial string used before the type. Should be "@" normally.
 ** Returns:	nothing
 **___________________________________________________			     */
-void put_record(fct,rec,db,start)		   /*                        */
+void put_record(fct, rec, db, start)		   /*                        */
   int	       (*fct)_ARG((int));		   /*                        */
   Record       rec;				   /*                        */
   DB	       db;				   /*                        */
@@ -517,7 +517,7 @@ void put_record(fct,rec,db,start)		   /*                        */
   switch ( RecordType(rec) )			   /*			     */
   { case BIB_COMMENT:				   /*			     */
 #ifdef OLD
-      indent(rsc_col_c,fct);			   /*			     */
+      indent(rsc_col_c, fct);			   /*			     */
       PUTS(*hp);				   /*			     */
       PUTC(' ');				   /*                        */
       NL;				   	   /*			     */
@@ -528,7 +528,7 @@ void put_record(fct,rec,db,start)		   /*                        */
       PUTS(EntryName(RecordType(rec)));	   	   /*			     */
       PUTC(open_brace);				   /*			     */
       indent(rsc_col_p,fct);			   /*			     */
-      line_breaking(*hp,rsc_col_p,fct);		   /*			     */
+      line_breaking(*hp, rsc_col_p, fct);	   /*			     */
       PUTC(' ');				   /*                        */
       PUTC(close_brace);			   /*                        */
       NL;				   	   /*			     */
@@ -537,7 +537,8 @@ void put_record(fct,rec,db,start)		   /*                        */
       PUTS(start);				   /*			     */
       PUTS(EntryName(RecordType(rec)));	   	   /*			     */
       PUTC(open_brace);				   /*			     */
-      print_equation(sym_empty,*hp,*(hp+1),rsc_col_s,fct);/*		     */
+      print_equation(sym_empty,			   /*                        */
+		     *hp, *(hp+1), rsc_col_s, fct);/*		             */
       PUTC(' ');				   /*                        */
       PUTC(close_brace);			   /*                        */
       NL;				   	   /*			     */
@@ -546,7 +547,8 @@ void put_record(fct,rec,db,start)		   /*                        */
       PUTS(start);				   /*			     */
       PUTS(EntryName(RecordType(rec)));	   	   /*			     */
       PUTC(open_brace);				   /*			     */
-      print_equation(sym_empty,*hp,*(hp+1),rsc_col_s,fct);/*		     */
+      print_equation(sym_empty,			   /*                        */
+		     *hp, *(hp+1), rsc_col_s, fct);/*		             */
       PUTC(' ');				   /*                        */
       PUTC(close_brace);			   /*                        */
       NL;				   	   /*			     */
@@ -591,7 +593,7 @@ void put_record(fct,rec,db,start)		   /*                        */
 			     fct);		   /*                        */
 	    }					   /*			     */
 	    else				   /* Otherwise print a key  */
-	    { indent(rsc_col_key,fct);		   /*			     */
+	    { indent(rsc_col_key, fct);		   /*			     */
 	      PUTS(get_key_name(*hp));      	   /*			     */
 	    }					   /*			     */
 	  }					   /*			     */
@@ -601,6 +603,6 @@ void put_record(fct,rec,db,start)		   /*                        */
       if (rsc_print_tc) { PUTC(','); }		   /*                        */
       NL;					   /*                        */
       PUTC(close_brace);	   	   	   /*                        */
-      for ( i=rsc_newlines; i>0; --i ) { NL; }	   /*                        */
+      for ( i = rsc_newlines; i > 0; --i ) { NL; } /*                        */
   }						   /*			     */
 }						   /*------------------------*/
